*Do-File for Analyzing Lab Data and Somali Survey Data

* Clear all macros and set stata version

version 16
clear all
macro drop _all
set more off

* Set the working directory to the Replication folder on your computer

****************************************

* load lab data
use  "AR_QJPS_LabData.dta", clear

** IN-TEXT DESCRIPTIVES **

ttest id_photo if AfImm==1, by(horn)
ttest firstgen if AfImm==1, by(horn)


** APPENDIX TABLES/FIGURES **

	* Table A.1 (tex table generated manually)
	
foreach dv in id_photo id_name id_video {
    ttest `dv' if AfImm==1, by(horn)
    }

	* Table A.2
foreach v in id_photo id_name id_video {
	eststo `v': reg `v' horn muslim firstgen male if AfImm==1
	}

esttab id_photo id_name id_video  ///
    using "Tables/idr.tex", replace ///
    title(Resistance to assimilation (No imputation) \label{tab:idr}) /// 
    nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout("\multicolumn{1}{c}{@}" ) labels("Observations") f(0)) ///
    nonotes   nobaselevels noomitted nodep ///
	mtitles("\shortstack{Photo\\Correct ID}" "\shortstack{Name\\Correct ID}" /// 
    "\shortstack{Video\\Correct ID}" )  
	
	
****************************************

* load survey data
use "AR_QJPS_SomaliSurvey.dta", clear


** IN-TEXT DESCRIPTIVES **

tab bantu
bys enumerator: tab female

foreach dv in  childspouse  assimilation2 {
ttest `dv', by(bantu)
}

foreach dv in coethspouse  childnamed  {
ttest `dv', by(bantu)
kwallis `dv', by(bantu)
}

tabstat disc_blackmoresom, by(bantu)
kwallis disc_blackmoresom, by(bantu)
ttest disc_black, by(bantu)

tabstat blackfriendd, by(bantu)
kwallis blackfriendd, by(bantu)
ttest pblack, by(bantu)

** MAIN PAPER TABLES/FIGURES **

preserve 
	* impute data
mdesc female age employed hh_income education_primary
mi set flong
mi misstable summarize female age employed hh_income education_primary
mi misstable patterns female age employed hh_income education_primary
mi register imputed female age employed hh_income education_primary
mi impute mvn female age employed hh_income education_primary , add(10) rseed(43201)
tempfile imputed
save `imputed'	

	* Table 1
	
foreach dv in coethspouse childspouse childnamed assimilation2  {
mi estimate, post: reg `dv' bantu female age employed hh_income education_primary secgen , robust
est sto `dv'_i
}

esttab coethspouse_i childspouse_i childnamed_i assimilation2_i  ///
    using "Tables/assimvar_i.tex", replace ///
    title(Resistance to assimilation \label{tab:assimvari}) /// 
    nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout( "\multicolumn{1}{c}{@}") labels( "Observations") f(0)) ///
    nonotes   nobaselevels noomitted nodep ///
	mtitles("\shortstack{Coethnic\\Spouse}" "\shortstack{Child\\Coethnic\\Spouse}" /// 
    "\shortstack{Child\\Ethnic\\Name}" "\shortstack{Resist\\Assim.\\Index}") 

	* Figure 1
	
mi estimate, post: reg assimilation2 i.bantu##i.secgen female age employed hh_income education_primary secgen , robust	
est sto assim2_i 

est restore assim2_i
mimrgns, by(secgen bantu) cmdmargins
marginsplot,  name(assimovertime1, replace) ///
	ytitle (Resistance to Cultural Assimilation) scheme(plotplainblind) ///
    title("") legend(pos(11) ring(0)) xscale(range(-0.25 1.25)) xlabel(0 "First Generation" 1 "Second Generation", nogrid) ///
	xtitle("") ///
	plot1opts(msymbol(O) mcolor(black) lcolor(black) ) ci1opts(lcolor(black) msiz(0))   ///
	plot2opts(msymbol(S) mcolor(gs10) lcolor(gs10) ) ci2opts(lcolor(gs10) msiz(0))   ///
	graphregion(fcolor(white) ilcolor(white) lcolor(white))
graph export "Figures/assimovergen.pdf", replace	

mi estimate, post: reg assimilation2 i.bantu##c.yrsinus female age employed hh_income education_primary , robust
est sto assim3_i 
	
est restore assim3_i
mimrgns, by(bantu) at(yrsinus=(1(2)25)) cmdmargins
marginsplot,  name(assimovertime2, replace) ///
	ytitle (Resistance to Cultural Assimilation) scheme(plotplainblind) ///
    title("") legend(pos(7) ring(0)) xscale(range(-0.25 1.25)) xlabel(, nogrid) ///
	plot1opts(msymbol(O) mcolor(black) lcolor(black) ) ci1opts(lcolor(black) msiz(0))   ///
	plot2opts(msymbol(S) mcolor(gs10) lcolor(gs10) ) ci2opts(lcolor(gs10) msiz(0))   ///
	graphregion(fcolor(white) ilcolor(white) lcolor(white))
graph export "Figures/assimovertime.pdf", replace	
	
restore //load non-imputed data
	
** APPENDIX TABLES/FIGURES
	
	* Figure A.2
	
catplot i_location, percent var1opts(sort(1) descending) scheme(s2mono) graphregion(fcolor(white)) ytitle("%")
graph export "Figures/location.pdf", replace

	* Figure A.3
	
catplot i_rel, percent scheme(s2mono) graphregion(fcolor(white)) ytitle("%")
graph export "Figures/know.pdf", replace

	* Table A.3
	
** See End of File **	
	
	* Table A.4
	
eststo culm2: estpost summ coethspouse childspouse childnamed assimilation2

esttab culm2  using "Tables/culm_summ2", replace booktabs ///
	cells((mean(fmt(3) label(\multicolumn{1}{c}{Mean})) sd(fmt(3)label(\multicolumn{1}{c}{Std. Dev.})) ///
	min(label(\multicolumn{1}{c}{Min.})) max(label(\multicolumn{1}{c}{Max.})) count(fmt(0) label(\multicolumn{1}{c}{N}))      ))  ///
	label par gaps lines nonum noobs compress unstack ///
	title(Summary statistics for resistance to assimilation\label{tab:culm}) ///
	alignment(D{.}{.}{-1}) substitute (l*{1} l*{5})  ///
    refcat(coethspouse "\textit{Endogamy}" childname "\textit{Ethnic Naming}" assimilation2 "\textit{Index}", nolabel)	
	
	* Table A.5

foreach dv in coethspouse childspouse childnamed assimilation2  {
eststo `dv'pap: reg `dv' bantu female age secgen edu hh_income employed english_fluent coethfriend democrat , robust
}	

esttab coethspousepap childspousepap childnamedpap assimilation2pap  ///
    using "Tables/assimvarpap.tex", replace ///
    title(Resistance to assimilation (PAP controls)\label{tab:assimvarpap}) /// 
    nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats(r2 N ,layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels("\$R^2$\" "Observations") f(2 0)) ///
    nonotes   nobaselevels noomitted nodep ///
	mtitles("\shortstack{Coethnic\\Spouse}" "\shortstack{Child\\Coethnic\\Spouse}" /// 
    "\shortstack{Child\\Ethnic\\Name}" "\shortstack{Resist\\Assim.\\Index}") 

	
	* Table A.6

foreach dv in coethspouse childspouse childnamed assimilation2  {
eststo `dv': reg `dv' bantu female age employed hh_income education_primary secgen , robust
}	

esttab coethspouse childspouse childnamed assimilation2  ///
    using "Tables/assimvar.tex", replace ///
    title(Resistance to assimilation (No imputation) \label{tab:assimvar}) /// 
   nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout("\multicolumn{1}{c}{@}" ) labels("Observations") f(0)) ///
    nonotes   nobaselevels noomitted nodep ///
	mtitles("\shortstack{Coethnic\\Spouse}" "\shortstack{Child\\Coethnic\\Spouse}" /// 
    "\shortstack{Child\\Ethnic\\Name}" "\shortstack{Resist\\Assim.}") 

	* Table A.7 (estimations produced under Figure 1 and Figure 2)
	
esttab assim2_i assim3_i  ///
    using "Tables/assim_i.tex", replace ///
    title(Resistance to assimilation by time in the US \label{tab:assimi}) /// 
    nostar se b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout("\multicolumn{1}{c}{@}") labels( "Observations") f(0)) ///
	varlabels (1.bantu "Bantu" 1.secgen "Second Generation" 1.bantu#1.secgen ///
	"Bantu $\times$ Second Generation" 1.bantu#c.yrsinus "Bantu $\times$ Years in US" _cons "Constant") ///
	order (1.bantu 1.secgen 1.bantu#1.secgen yrsinus 1.bantu#c.yrsinus ) ///
    nonotes nonum  nobaselevels noomitted nodep ///
    mtitles("\shortstack{Resist\\Assim.\\Index}" "\shortstack{Resist\\Assim.\\Index}")

	* Table A.8 
eststo assim2: reg assimilation2 i.bantu##i.secgen female age employed hh_income education_primary secgen , robust
eststo assim3: reg assimilation2 i.bantu##c.yrsinus female age employed hh_income education_primary , robust

esttab assim2 assim3  ///
    using "Tables/assim.tex", replace ///
    title(Resistance to assimilation by time in the US (No imputation) \label{tab:assim}) /// 
    nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout( "\multicolumn{1}{c}{@}") labels( "Observations") f(0)) ///
	varlabels (1.bantu "Bantu" 1.secgen "Second Generation" 1.bantu#1.secgen ///
	"Bantu $\times$ Second Generation" 1.bantu#c.yrsinus "Bantu $\times$ Years in US" _cons "Constant" ) ///
	order (1.bantu 1.secgen 1.bantu#1.secgen yrsinus 1.bantu#c.yrsinus) ///
    nonotes   nobaselevels noomitted nodep ///
    mtitles("\shortstack{Resist\\Assim.\\Index}" "\shortstack{Resist\\Assim.\\Index}" )

	* Table A.9 
	
preserve //load imputed data
use `imputed' , clear
lab define hhhilo 0 "Higher Income" 1 "Lower Income"
lab val hhincome_less20 hhhilo

mi estimate, post: reg assimilation2 i.bantu##i.secgen##i.hhincome_less20 female age employed hh_income education_primary secgen , robust
est sto income1
mi estimate, post: reg assimilation2 i.bantu##c.yrsinus##i.hhincome_less20 female age employed hh_income education_primary , robust
est sto income2

esttab income1 income2  ///
    using "Tables/income.tex", replace ///
    title(Resistance to assimilation by houshold income and time in the US \label{tab:income}) /// 
    nostar se b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout("\multicolumn{1}{c}{@}") labels( "Observations") f(0)) ///
	varlabels (1.bantu "Bantu" 1.secgen "Second Generation" 1.bantu#1.secgen ///
	"Bantu $\times$ Second Generation" 1.bantu#c.yrsinus "Bantu $\times$ Years in US" ///
	1.bantu#1.secgen#1.hhincome_less20 "Bantu $\times$ Second Generation $\times$ Lower Income"  1.bantu#1.hhincome_less20 "Bantu $\times$ Lower Income" 1.secgen#1.hhincome_less20 "Second Genderation $\times$ Lower Income" ///
	_cons "Constant") ///
	order (1.bantu 1.hhincome_less20 1.bantu#1.hhincome_less20 1.secgen  1.bantu#1.secgen  1.secgen#1.hhincome_less20 1.bantu#1.secgen#1.hhincome_less20  yrsinus 1.bantu#c.yrsinus c.yrsinus#1.hhincome_less20 1.bantu#c.yrsinus#1.hhincome_less20) ///
    nonotes nonum  nobaselevels noomitted nodep ///
    mtitles("\shortstack{Resist\\Assim.\\Index}" "\shortstack{Resist\\Assim.\\Index}")

	* Figure A.7

est restore income1
mimrgns, by( secgen bantu hhincome_less20) cmdmargins
marginsplot,  name(income1, replace) ///
	ytitle (Resistance to Cultural Assimilation) scheme(plotplainblind) ///
    title("") legend(pos(7) ring(0)) xscale(range(-0.25 1.25)) xlabel(0 "First Generation" 1 "Second Generation", nogrid) ///
	xtitle("") ///
	plot1opts(msymbol(O) mcolor(black) lcolor(black) lpattern(solid) ) ci1opts(lcolor(black) msiz(0))   ///
	plot2opts(msymbol(D) mcolor(black) lcolor(black) lpattern(dash) ) ci2opts(lcolor(black) msiz(0))   ///
	plot3opts(msymbol(S) mcolor(gs10) lcolor(gs10) lpattern(solid) ) ci3opts(lcolor(gs10) msiz(0))   ///
	plot4opts(msymbol(T) mcolor(gs10) lcolor(gs10) lpattern(dash) ) ci4opts(lcolor(gs10) msiz(0))   ///
	graphregion(fcolor(white) ilcolor(white) lcolor(white))
graph export "Figures/income1.pdf", replace	

est restore income2
mimrgns, by(bantu hhincome_less20 ) at(yrsinus=(1(2)25)) cmdmargins
marginsplot,  name(income2, replace) ///
	ytitle (Resistance to Cultural Assimilation) scheme(plotplainblind) ///
    title("") legend(pos(7) ring(0) ) xscale(range(-0.25 1.25)) xlabel(, nogrid) ///
	plot1opts(msymbol(O) mcolor(black) lcolor(black) lpattern(solid) ) ci1opts(lcolor(black) msiz(0))   ///
	plot2opts(msymbol(D) mcolor(black) lcolor(black) lpattern(dash) ) ci2opts(lcolor(black) msiz(0))   ///
	plot3opts(msymbol(S) mcolor(gs10) lcolor(gs10) lpattern(solid) ) ci3opts(lcolor(gs10) msiz(0))   ///
	plot4opts(msymbol(T) mcolor(gs10) lcolor(gs10) lpattern(dash) ) ci4opts(lcolor(gs10) msiz(0))   ///
	graphregion(fcolor(white) ilcolor(white) lcolor(white))
graph export "Figures/income2.pdf", replace

	* Table A.10
	
mi estimate, post: reg disc_blackmoresom bantu female age employed hh_income education_primary secgen , robust
eststo reldisc
mi estimate, post: reg disc_black bantu female age employed hh_income education_primary secgen , robust
eststo disc_black_i

esttab reldisc disc_black_i   ///
    using "Tables/reldisc.tex", replace ///
    title(Perceived severity of racial discrimination by ethnic group \label{tab:reldisc}) /// 
    nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout( "\multicolumn{1}{c}{@}") labels( "Observations") f(0)) ///
    nonotes   nobaselevels noomitted nodep ///
	mtitles("\shortstack{Black\\More\\Ethnic}" "\shortstack{Rank\\of\\Race}" )  

	* Table A.11
mi estimate, post: reg  blackfriendd bantu female age employed hh_income education_primary secgen   , robust
est sto blackfriend1 
mi estimate, post: reg  blackfriend bantu female age employed hh_income education_primary secgen   , robust
est sto blackfriend2
mi estimate, post: reg  pblack bantu female age employed hh_income education_primary secgen   , vce(cluster zipcode)
est sto pblack 

esttab blackfriend1 blackfriend2 pblack   ///
    using "Tables/distance.tex", replace ///
    title(Distancing from African Americans by ethnic group \label{tab:distance}) /// 
    nostar se ar2 b(3) se(3) ar2(3) label booktabs alignment(D{.}{.}{-1})  /// 
    stats( N ,layout( "\multicolumn{1}{c}{@}") labels( "Observations") f(0)) ///
    nonotes   nobaselevels noomitted nodep ///
	mtitles("\shortstack{Any\\Black\\Friend}" "\shortstack{No. of\\Black\\Friends}" "\shortstack{Percent \\Black\\Zipcode}" )  
	
restore //load non-imputed data

* Table A.3

eststo demo: estpost summ bantu female age children muslim employed education_primary education_sec ///
    hhincome_less20 hhincome_2040 hhincome_more40 ///
    immgen1 immgen2 immgen3 bornus age_arrival yrsinus

foreach v of varlist  education_primary education_sec ///
    hhincome_less20 hhincome_2040 hhincome_more40 ///
    immgen1 immgen2 immgen3  {
	label variable `v' `"\hspace{0.1cm} `: variable label `v''"'
	}
esttab demo  using "Tables/demo_summ", replace booktabs ///
	cells((mean(fmt(3) label(\multicolumn{1}{c}{Mean})) sd(fmt(3)label(\multicolumn{1}{c}{Std. Dev.})) ///
	min(label(\multicolumn{1}{c}{Min.})) max(label(\multicolumn{1}{c}{Max.})) count(fmt(0) label(\multicolumn{1}{c}{N}))      ))  ///
	label par gaps lines nonum noobs compress unstack ///
	title(Demographic Characteristics of the Sample\label{tab:demo}) ///
	alignment(D{.}{.}{-1}) substitute (l*{1} l*{5})  ///
    refcat(education_primary "\textit{Education Completed}" hhincome_less20 "\textit{Household Income}" ///
    immgen1 "\textit{Immigrant Generation}" , nolabel)
